# coding: utf-8

"""
    University Student API

    This API exposes identity information about university students. The purpose of this API is to give access to basic identity information about university students for use by downstream systems, therefore the data exposed is limited to basic information about who a student is and which institutions they are affiliated with.  This API uses the following identifiers to link people to person-records held within different systems:  * `person.v1.student-records.university.identifiers.cam.ac.uk` - the university student (ust) identifier of this person -   also referred to as USN  Additionally this API uses the following identifiers to link people to institutions or entities which a person may have an affiliation to:  * `institution.v1.student-records.university.identifiers.cam.ac.uk` - the university student (ust) institution identifier.     This encompasses colleges, departments and faculties. The     [CamSIS Coding Manual](https://www.camsis.cam.ac.uk/technical/camsis-coding-manual)     lists the available values for this affiliation (under A01 and M01). * `academic-plan.v1.student-records.university.identifiers.cam.ac.uk` - the university student (ust) academic plan     identifier. The     [CamSIS Coding Manual](https://www.camsis.cam.ac.uk/technical/camsis-coding-manual)     lists the available values for this affiliation (under D07).  Both affiliations provide a `status` field which indicate a student's status within an affiliated entity. This `status` field is the short representation of the academic career field held in CamSIS. The [CamSIS Coding Manual](https://www.camsis.cam.ac.uk/technical/camsis-coding-manual) lists the available values for the `status` field (under D05).  This API is currently backed by data from CamSIS, exposing a view of data that is refreshed nightly.  

    The version of the OpenAPI document: v1alpha2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Optional
from pydantic import BaseModel, Field

class Student(BaseModel):
    """
    A representation of a student - exposing the bare minimum information to identify a student and link them to affiliated institutions and programmes within the University.
    """
    affiliations: Optional[Any] = Field(..., description="The list of entities that this student is affiliated with. Currently this includes college and department affiliations (under the scheme `institution.v1.student-records.university.identifiers.cam.ac.uk`) and any active academic plan (under the scheme `institution.v1.student-records.university.identifiers.cam.ac.uk`).")
    date_of_birth: Optional[Any] = Field(None, alias="dateOfBirth", description="The date of birth of this student. There are a minority of cases where this is not known.")
    forenames: Optional[Any] = Field(..., description="The forenames of this student, split by a single space.")
    identifiers: Optional[Any] = Field(..., description="The identifiers attached to this student record. Currently only identifiers of the scheme person.v1.student-records.university.identifiers.cam.ac.uk (USN) are included, but additional identifier types may be added in future.")
    name_prefixes: Optional[Any] = Field(..., alias="namePrefixes", description="The name prefixes of this student, split by a single space.")
    surname: Optional[Any] = Field(..., description="The surname of this student.")
    __properties = ["affiliations", "dateOfBirth", "forenames", "identifiers", "namePrefixes", "surname"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Student:
        """Create an instance of Student from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if affiliations (nullable) is None
        # and __fields_set__ contains the field
        if self.affiliations is None and "affiliations" in self.__fields_set__:
            _dict['affiliations'] = None

        # set to None if date_of_birth (nullable) is None
        # and __fields_set__ contains the field
        if self.date_of_birth is None and "date_of_birth" in self.__fields_set__:
            _dict['dateOfBirth'] = None

        # set to None if forenames (nullable) is None
        # and __fields_set__ contains the field
        if self.forenames is None and "forenames" in self.__fields_set__:
            _dict['forenames'] = None

        # set to None if identifiers (nullable) is None
        # and __fields_set__ contains the field
        if self.identifiers is None and "identifiers" in self.__fields_set__:
            _dict['identifiers'] = None

        # set to None if name_prefixes (nullable) is None
        # and __fields_set__ contains the field
        if self.name_prefixes is None and "name_prefixes" in self.__fields_set__:
            _dict['namePrefixes'] = None

        # set to None if surname (nullable) is None
        # and __fields_set__ contains the field
        if self.surname is None and "surname" in self.__fields_set__:
            _dict['surname'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Student:
        """Create an instance of Student from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Student.parse_obj(obj)

        _obj = Student.parse_obj({
            "affiliations": obj.get("affiliations"),
            "date_of_birth": obj.get("dateOfBirth"),
            "forenames": obj.get("forenames"),
            "identifiers": obj.get("identifiers"),
            "name_prefixes": obj.get("namePrefixes"),
            "surname": obj.get("surname")
        })
        return _obj


